/**
 *  Node class
 *
 * An object that contains a reference to a Object object and a 
 * reference to another Node. Allows a Node to be inserted into a list
 * at construction. Supports linking a subsequent object to this Node,
 * will return the reference to the next Node, or the reference to the 
 * data Object. However, the data object is immutable once
 * the object is constructed.
 *
 * @author Dominic Jonak, et al.
 * @Date 9/25/02
 */


public class Node
{
    private Comparable value;
    private Node next;

    /**
     *	constructor builds the Node with the supplied parameters
     *
     *	@param data object (must be Comparable)
     *	@param link  to a next Node, or null
     */

    public Node(Comparable initValue, Node initNext)
    {
	value = initValue;
	next = initNext;
    }

    /**
     *	returns reference to the next Node
     *
     *	@return next reference
     */
    
    public Node getNext() 
    {
	return next;	
    }
		
    /**
     *	sets the next reference of this object to the paramter object
     *
     *	@param next Node
     */

    public void setNext(Node obj) 
    {
	next = obj;	
    }
		
    /**
     *	returns reference to the data value of the object
     *
     *	@return reference to the Comparable data in the Node
     */

    public Comparable getData() 
    {
	return value;	
    }
}
